@@ -18,6 +18,12 @@ from .lint_parsers import display_lint_logs, parse_flake8_logs, parse_pylint_jso
 from .settings import SETTINGS
 
 
+@lru_cache(maxsize=1)
+def smart_exec(executable: str) -> str:
+    """Assumes executable is in the same directory as Python."""
+    return str(Path(sys.executable).parent / executable)
+
+
 @lru_cache(maxsize=1)
 def run_mod() -> str:
     """Return the currently active Python."""
@@ -44,7 +50,7 @@ def user_task(actions: Iterable[DoitAction], verbosity: int = 2) -> DoitTask:
 
 
 @beartype
-def task__priv_update() -> DoitTask:
+def task___update() -> DoitTask:
     """Run update operations and update the requirements file.
 
     Returns:
@@ -55,7 +61,7 @@ def task__priv_update() -> DoitTask:
         [
             Interactive('poetry lock --no-update'),
             Interactive(
-                'poetry export --format=requirements.txt --output=requirements.txt --without-hashes',
+                'poetry export --format=requirements.txt --output=requirements.txt --without-hashes --with=dev',
             ),
         ],
     )
@@ -72,7 +78,7 @@ def task_play() -> DoitTask:
 
     """
     return user_task([
-        Interactive(f'{run_mod()} -m game.play'),
+        Interactive(f'{run_mod()} game.play'),
     ])
 
 
@@ -80,7 +86,7 @@ def task_play() -> DoitTask:
 
 
 @beartype
-def task__priv_format() -> DoitTask:
+def task___format() -> DoitTask:
     """Format all project code and not just the tasks.
 
     Returns:
@@ -118,6 +124,19 @@ def task_format() -> DoitTask:
     ])
 
 
+@beartype
+def task___test() -> DoitTask:
+    """Run all tests using Pytest.
+
+    Returns:
+        DoitTask: doit task
+
+    """
+    return user_task([
+        Interactive(f'{run_mod()} pytest tests {SETTINGS.ARGS_PYTEST}'),
+    ])
+
+
 @beartype
 def task_test() -> DoitTask:
     """Run all tests marked with 'tasks' using Pytest.
@@ -187,7 +206,7 @@ def _lint_python(paths: str) -> list[DoitAction]:
 
 
 @beartype
-def task__priv_check() -> DoitTask:
+def task___check() -> DoitTask:
     """Format all project code and not just the tasks.
 
     Returns:
@@ -217,8 +236,17 @@ def _log_pyreverse_file_locations(diagrams_dir: Path) -> None:
 
 
 @beartype
-def task__priv_build_diagrams() -> DoitTask:
-    """Create shareable code diagrams for entire project.
+def __build_diagrams(package: str, diagrams_dir: Path) -> DoitTask:
+    return debug_task([
+        (partial(diagrams_dir.mkdir, exist_ok=True), ()),
+        f'{smart_exec("pyreverse")} {package} --output png --output-directory={diagrams_dir.as_posix()}',
+        (_log_pyreverse_file_locations, (diagrams_dir,)),
+    ])
+
+
+@beartype
+def task__build_diagrams() -> DoitTask:
+    """Create shareable code diagrams for the entire game folder.
 
     Returns:
         DoitTask: doit task
@@ -226,11 +254,7 @@ def task__priv_build_diagrams() -> DoitTask:
     """
     package = 'game'
     diagrams_dir = Path(package) / 'diagrams'
-    return debug_task([
-        (partial(diagrams_dir.mkdir, exist_ok=True), ()),
-        f'poetry run pyreverse {package} --output png --output-directory={diagrams_dir.as_posix()}',
-        (_log_pyreverse_file_locations, (diagrams_dir,)),
-    ])
+    return __build_diagrams(package, diagrams_dir)
 
 
 @beartype
@@ -244,34 +268,53 @@ def task_build_diagrams() -> DoitTask:
     task_dir = SETTINGS.task_dir()
     package = task_dir.as_posix().replace('/', '.')
     diagrams_dir = task_dir / 'diagrams'
-
-    return user_task([
-        (partial(diagrams_dir.mkdir, exist_ok=True), ()),
-        f'poetry run pyreverse {package} --output png --output-directory={diagrams_dir.as_posix()}',
-        (_log_pyreverse_file_locations, (diagrams_dir,)),
-    ])
+    return __build_diagrams(package, diagrams_dir)
 
 
 # ================== Optional Tasks ==================
 
 
 @beartype
-def task_watch_changes() -> DoitTask:
+def _build_ptw(pytest_args: str) -> DoitTask:
+    """Note: when not installed with poetry: `No such file or directory: 'pytest'`."""
+    def print_warning():
+        console = Console()
+        console.print('Warning: this task only works when installed with poetry', style='bold yellow')
+
+    task_dir = SETTINGS.task_dir().as_posix()
+    return {
+        'actions': [
+            (print_warning, ()),
+            Interactive(f'poetry run ptw "{task_dir}" {pytest_args} {SETTINGS.ARGS_PYTEST}')
+        ],
+        'verbosity': 2,
+    }
+
+
+@beartype
+def task___watch_changes() -> DoitTask:
     """Re-run tests on changes with pytest watcher.
 
     Returns:
         DoitTask: doit task
 
     """
-    task_dir = SETTINGS.task_dir().as_posix()
-    return {
-        'actions': [Interactive(f'{run_mod()} ptw "{task_dir}" {SETTINGS.ARGS_PYTEST}')],
-        'verbosity': 2,
-    }
+    return _build_ptw('')
 
 
 @beartype
-def task__priv_check_types() -> DoitTask:
+def task_watch_changes() -> DoitTask:
+    """Re-run tests tagged with tasks on changes with pytest watcher.
+
+    Returns:
+        DoitTask: doit task
+
+    """
+    return _build_ptw('--disable-warnings -m tasks')
+
+
+@beartype
+def task___check_types() -> DoitTask:
     """Run type annotation checks with MyPy against the entire package.
 
     Returns:
